package com.fastservice.app.activities;

import android.app.Activity;
import android.app.Fragment;
import android.content.Context;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ExpandableListView;

import com.fastservice.app.R;
import com.fastservice.app.conections.BD;
import com.fastservice.app.model.ExpandableListAdapter;
import com.fastservice.app.utils.Utils;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;


public class ListaArticulosFragment extends Fragment {

    private ListenerListaArticulos mListener;
    private Context context = this.getActivity();
    private String idRestaurante;

    String carta_o_menu;
    String accion;
    String tipo_plato;
    String idMenu;

    List<String> tiposArticulo;
    List<String> articulos;
    Map<String, List<String>> coleccionArticulos;
    ExpandableListView expListView;


    public ListaArticulosFragment() {
        // Required empty public constructor
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        BD bd = new BD();
        JSONObject ticketAbierto = null;
        try {
            ticketAbierto = bd.obtenerTicketAbiertoDeUsuario(Utils.getLoggedUser(getActivity())).getJSONObject(0);
            if (ticketAbierto == null){
                Utils.showTimeoutAlert(context);
            }
            else{
                idRestaurante = ticketAbierto.getString("id_restaurante");
            }
        } catch (JSONException e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onResume() {
        super.onResume();


        Bundle extras = getActivity().getIntent().getExtras();
        carta_o_menu = extras.getString("carta_o_menu", null);
        accion = extras.getString("accion", null);
        tipo_plato = extras.getString("tipo_plato", null);
        idMenu = extras.getString("idMenu", null);

        obtenerArticulosDeLaBD();


        expListView = (ExpandableListView) getView().findViewById(R.id.expandableArticulosList);
        final ExpandableListAdapter expListAdapter = new ExpandableListAdapter(
                getActivity(), tiposArticulo, coleccionArticulos);
        expListView.setAdapter(expListAdapter);

        //setGroupIndicatorToRight();

        expListView.setOnChildClickListener(new ExpandableListView.OnChildClickListener() {

            public boolean onChildClick(ExpandableListView parent, View v,
                                        int groupPosition, int childPosition, long id) {
                final String selected = (String) expListAdapter.getChild(
                        groupPosition, childPosition);
                mListener.onListItemClick(selected);
                //Utils.showToast(getActivity(), selected);

                return true;
            }
        });
        if (carta_o_menu.equals("menu")){
            expListView.expandGroup(0);
        }
    }

    private void obtenerArticulosDeLaBD(){

        List<String> entrantes = new ArrayList<String>();
        List<String> primeros = new ArrayList<String>();
        List<String> segundos = new ArrayList<String>();
        List<String> postres = new ArrayList<String>();
        List<String> bebidas = new ArrayList<String>();

        BD bd = new BD();
        JSONArray articulosBD = new JSONArray();
        if(carta_o_menu != null){
            if (carta_o_menu.equals("carta")){
                articulosBD = bd.obtenerArticulosdeRestaurante(idRestaurante);
                if (articulosBD == null){
                    Utils.showTimeoutAlert(context);
                }
            }
            else if (carta_o_menu.equals("menu")){
                if (accion != null && tipo_plato != null){
                    articulosBD = bd.obtenerArticulosdeRestaurantePorTipoArticuloYMenu(idRestaurante,tipo_plato,idMenu);
                    if (articulosBD == null){
                        Utils.showTimeoutAlert(context);
                    }
                }
            }
        }
        try {
            for (int i = 0; i< articulosBD.length();i++){
                JSONObject articulo = articulosBD.getJSONObject(i);
                if(articulo.getString("tipo_articulo").equals("Entrante")){
                    entrantes.add(articulo.getString("nombre"));
                }
                else if(articulo.getString("tipo_articulo").equals("Primero")){
                    primeros.add(articulo.getString("nombre"));
                }
                else if(articulo.getString("tipo_articulo").equals("Segundo")){
                    segundos.add(articulo.getString("nombre"));
                }
                else if(articulo.getString("tipo_articulo").equals("Postre")){
                    postres.add(articulo.getString("nombre"));
                }
                else if(articulo.getString("tipo_articulo").equals("Bebida")){
                    bebidas.add(articulo.getString("nombre"));
                }
            }
        }catch (JSONException e) {
            e.printStackTrace();
        }


        tiposArticulo = new ArrayList<String>();
        if(!entrantes.isEmpty()){
            tiposArticulo.add("Entrantes");
        }
        if(!primeros.isEmpty()){
            tiposArticulo.add("Primer Plato");
        }
        if(!segundos.isEmpty()){
            tiposArticulo.add("Segundo Plato");
        }
        if(!postres.isEmpty()){
            tiposArticulo.add("Postre");
        }
        if(!bebidas.isEmpty()){
            tiposArticulo.add("Bebidas");
        }

        coleccionArticulos = new LinkedHashMap<String, List<String>>();

        for (String articulo : tiposArticulo) {
            if (articulo.equals("Entrantes")) {
                articulos = entrantes;
            } else if (articulo.equals("Primer Plato"))
                articulos = primeros;
            else if (articulo.equals("Segundo Plato"))
                articulos = segundos;
            else if (articulo.equals("Postre"))
                articulos = postres;
            else if (articulo.equals("Bebidas"))
                articulos = bebidas;

            coleccionArticulos.put(articulo, articulos);
        }
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        // Inflate the layout for this fragment
        super.onCreateView(inflater,container,savedInstanceState);
        return inflater.inflate(R.layout.fragment_lista_articulos, container, false);
    }

    @Override
    public void onAttach(Activity activity) {
        super.onAttach(activity);
        try {
            mListener = (ListenerListaArticulos) activity;
        } catch (ClassCastException e) {
            throw new ClassCastException(activity.toString()
                    + " must implement OnFragmentInteractionListener");
        }
    }

    @Override
    public void onDetach() {
        super.onDetach();
        mListener = null;
    }

    /**
     * This interface must be implemented by activities that contain this
     * fragment to allow an interaction in this fragment to be communicated
     * to the activity and potentially other fragments contained in that
     * activity.
     * <p>
     * See the Android Training lesson <a href=
     * "http://developer.android.com/training/basics/fragments/communicating.html"
     * >Communicating with Other Fragments</a> for more information.
     */
    public interface ListenerListaArticulos {
        public void onListItemClick(String id);
    }

}
