package com.fastservice.app.activities;

import android.content.Context;
import android.content.Intent;
import android.content.res.Configuration;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.support.v4.app.ActionBarDrawerToggle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.support.v4.view.GravityCompat;
import android.support.v4.widget.DrawerLayout;
import android.view.Display;
import android.view.MenuItem;
import android.view.Surface;
import android.view.View;
import android.view.WindowManager;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;

import com.fastservice.app.R;
import com.fastservice.app.conections.BD;
import com.fastservice.app.utils.Constants;
import com.fastservice.app.utils.Utils;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;

public class ListaHistorialActivity extends FragmentActivity implements ListaHistorialFragment.ListenerListaHistorial{

    private DrawerLayout mDrawerLayout;
    private ListView mDrawerList;
    private ActionBarDrawerToggle mDrawerToggle;

    private CharSequence mDrawerTitle;
    private CharSequence mTitle;
    private String[] mPlanetTitles = "Pedido Actual,Ver Ayuda,Logout".split(",");

    private ListView listaHistorico;
    private ArrayList<String> listaIds = new ArrayList<String>();

    private Context context = this;

    @Override
    protected void onCreate(Bundle savedInstanceState) {

        super.onCreate(savedInstanceState);
        setContentView(R.layout.lista_historial_activity);

        mTitle = mDrawerTitle = getTitle();
        //mPlanetTitles = getResources().getStringArray(R.array.planets_array);
        mDrawerLayout = (DrawerLayout) findViewById(R.id.drawer_layout);
        mDrawerList = (ListView) findViewById(R.id.left_drawer);

        // set a custom shadow that overlays the main content when the drawer opens
        mDrawerLayout.setDrawerShadow(R.drawable.drawer_shadow, GravityCompat.START);
        // set up the drawer's list view with items and click listener
        mDrawerList.setAdapter(new ArrayAdapter<String>(this,
                R.layout.drawer_list_item, mPlanetTitles));
        mDrawerList.setOnItemClickListener(new DrawerItemClickListener());

        // enable ActionBar app icon to behave as action to toggle nav drawer
        getActionBar().setDisplayHomeAsUpEnabled(true);
        getActionBar().setHomeButtonEnabled(true);
        getActionBar().setBackgroundDrawable(new ColorDrawable(Color.parseColor("#ff800202")));

        // ActionBarDrawerToggle ties together the the proper interactions
        // between the sliding drawer and the action bar app icon
        mDrawerToggle = new ActionBarDrawerToggle(
                this,                  /* host Activity */
                mDrawerLayout,         /* DrawerLayout object */
                R.drawable.ic_drawer,  /* nav drawer image to replace 'Up' caret */
                R.string.drawer_open,  /* "open drawer" description for accessibility */
                R.string.drawer_close  /* "close drawer" description for accessibility */
        ) {
            public void onDrawerClosed(View view) {
                //getActionBar().setTitle(mTitle);
                invalidateOptionsMenu(); // creates call to onPrepareOptionsMenu()
            }

            public void onDrawerOpened(View drawerView) {
                //getActionBar().setTitle(mDrawerTitle);
                invalidateOptionsMenu(); // creates call to onPrepareOptionsMenu()
            }
        };
        mDrawerLayout.setDrawerListener(mDrawerToggle);

        if (savedInstanceState == null) {
            selectItem(0);
        }
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        if (mDrawerToggle.onOptionsItemSelected(item)) {
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    protected void onResume() {
        super.onResume();
        setTitle("Historial de Pedidos");
        ListaHistorialFragment lista = (ListaHistorialFragment) getSupportFragmentManager().findFragmentById(R.id.fragment_lista_historial);

        obtenerIdsHistoricoDeLaBD();
        listaHistorico = lista.getListView();
    }

    private void obtenerIdsHistoricoDeLaBD(){
        BD bd = new BD();
        JSONArray tickets = bd.obtenerHistoricoDelUsuario(Utils.getLoggedUser(this));
        if (tickets == null){
            Utils.showTimeoutAlert(context);
        }
        else{
            for (int i =0; i<tickets.length(); i++){
                JSONObject ticket = null;
                try {
                    ticket = tickets.getJSONObject(i);
                    listaIds.add(ticket.getString("id_ticket"));
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        }

    }

    @Override
    public void onListItemClick(int posicion) {

        WindowManager mWindowManager = (WindowManager) getSystemService(WINDOW_SERVICE);
        Display mDisplay = mWindowManager.getDefaultDisplay();
        //Si esta en posicion apaisado, cargamos el fragment de detalles y lo actualizamos
        if(mDisplay.getRotation() != Surface.ROTATION_0 &&  mDisplay.getRotation() != Surface.ROTATION_180) {
            DetallesHistorialFragment detalles = (DetallesHistorialFragment) getFragmentManager().findFragmentById(R.id.fragment_detalle_historial);
            detalles.visualizarDetalles(listaIds.get(posicion));
        } else {
            //Si esta en posicion retrato, llamamos a la activity con el detalle de la oferta.
            Intent i = new Intent(getApplicationContext(), DetallesHistorialActivity.class);
            //Log.i("AQUI RECIBO EL ID Y ENVIO EN EL INTENT", id);
            i.putExtra(Constants.Historial_Seleccionado, listaIds.get(posicion));
            startActivity(i);
        }
    }


    /* The click listner for ListView in the navigation drawer */
    private class DrawerItemClickListener implements ListView.OnItemClickListener {
        @Override
        public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
            selectItem(position);
            switch (position){
                case 0://Pedido Actual
                    String loggedUser = Utils.getLoggedUser(context);
                    if(loggedUser!=null){
                        Intent intent = new Intent(ListaHistorialActivity.this,InstruccionesActivity.class);
                        BD bd = new BD();
                        JSONArray ticketsPentientes = bd.obtenerTicketAbiertoDeUsuario(Utils.getLoggedUser(context));
                        if (ticketsPentientes == null){
                            Utils.showTimeoutAlert(context);
                        }
                        else{
                            if (ticketsPentientes.length()!=0){
                                intent = new Intent(ListaHistorialActivity.this,PedidoActivity.class)
                                        .addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP | Intent.FLAG_ACTIVITY_SINGLE_TOP);
                            }
                            startActivity(intent);
                            finish();
                        }

                    }
                    break;
                case 1://Ayuda
                    Intent i = new Intent (ListaHistorialActivity.this, AyudaActivity.class);
                    startActivity(i);
                    break;
                case 2://Logout
                    Utils.logout(getApplicationContext());
                    Intent intent = new Intent(ListaHistorialActivity.this, LoginActivity.class);
                    intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
                    startActivity(intent);
                    finish();
                    break;
                default:
                    break;
            }
        }
    }

    private void selectItem(int position) {
        // update the main content by replacing fragments
        Fragment fragment = new PlanetFragment();
        Bundle args = new Bundle();
        args.putInt(PlanetFragment.ARG_PLANET_NUMBER, position);
        fragment.setArguments(args);

        FragmentManager fragmentManager = getSupportFragmentManager();
        fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).commit();

        // update selected item and title, then close the drawer
        mDrawerList.setItemChecked(position, true);
        setTitle(mPlanetTitles[position]);
        mDrawerLayout.closeDrawer(mDrawerList);
    }


    @Override
    public void setTitle(CharSequence title) {
        mTitle = title;
        getActionBar().setTitle(mTitle);
    }

    /**
     * When using the ActionBarDrawerToggle, you must call it during
     * onPostCreate() and onConfigurationChanged()...
     */

    @Override
    protected void onPostCreate(Bundle savedInstanceState) {
        super.onPostCreate(savedInstanceState);
        // Sync the toggle state after onRestoreInstanceState has occurred.
        mDrawerToggle.syncState();
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        // Pass any configuration change to the drawer toggls
        mDrawerToggle.onConfigurationChanged(newConfig);
    }

    /**
     * Fragment that appears in the "content_frame", shows a planet
     */
    public static class PlanetFragment extends Fragment {
        public static final String ARG_PLANET_NUMBER = "planet_number";

        public PlanetFragment() {
            // Empty constructor required for fragment subclasses
        }
    }



}