package com.fastservice.app.activities;

import android.app.ActionBar;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.os.AsyncTask;
import android.os.Bundle;
import android.text.Html;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

import com.fastservice.app.R;
import com.fastservice.app.conections.BD;
import com.fastservice.app.utils.Utils;
import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.GooglePlayServicesUtil;
import com.google.android.gms.gcm.GoogleCloudMessaging;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.IOException;

public class LoginActivity extends Activity {

    private TextView register;
    private EditText user,password;
    private Button login;
    private BD bd = new BD();
    //GCM
    GoogleCloudMessaging gcm;
    String regid;
    Context context = this;
    public static final String EXTRA_MESSAGE = "message";
    public static final String PROPERTY_REG_ID = "registration_id";
    private static final String PROPERTY_APP_VERSION = "appVersion";
    private final static int PLAY_SERVICES_RESOLUTION_REQUEST = 9000;
    String SENDER_ID = "661523966397";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        context = this;
        super.onCreate(savedInstanceState);
        setContentView(R.layout.login_activity);
        if (checkPlayServices()) {
            gcm = GoogleCloudMessaging.getInstance(this);
            regid = getRegistrationId(context);

            if (regid.isEmpty()) {
                registerInBackground();
            }
        } else {
            Log.i("FastService GCM", "No valid Google Play Services APK found.");
        }
    }

    private String getRegistrationId(Context context) {
        final SharedPreferences prefs = getGCMPreferences(context);
        String registrationId = prefs.getString(PROPERTY_REG_ID, "");
        if (registrationId.isEmpty()) {
            Log.i("FastService GCM", "Registration not found.");
            return "";
        }
        // Check if app was updated; if so, it must clear the registration ID
        // since the existing regID is not guaranteed to work with the new
        // app version.
        int registeredVersion = prefs.getInt(PROPERTY_APP_VERSION, Integer.MIN_VALUE);
        int currentVersion = getAppVersion(context);
        if (registeredVersion != currentVersion) {
            Log.i("FastService GCM", "App version changed.");
            return "";
        }
        return registrationId;
    }

    private SharedPreferences getGCMPreferences(Context context) {
        // This sample app persists the registration ID in shared preferences, but
        // how you store the regID in your app is up to you.
        return getSharedPreferences(LoginActivity.class.getSimpleName(),
                Context.MODE_PRIVATE);
    }

    private static int getAppVersion(Context context) {
        try {
            PackageInfo packageInfo = context.getPackageManager()
                    .getPackageInfo(context.getPackageName(), 0);
            return packageInfo.versionCode;
        } catch (PackageManager.NameNotFoundException e) {
            // should never happen
            throw new RuntimeException("Could not get package name: " + e);
        }
    }

    private void registerInBackground() {
        new AsyncTask<Void,String,String>() {
            @Override
            protected String doInBackground(Void... params) {
                String msg = "";
                try {
                    if (gcm == null) {
                        gcm = GoogleCloudMessaging.getInstance(context);
                    }
                    regid = gcm.register(SENDER_ID);
                    msg = "Device registered, registration ID=" + regid;
                    storeRegistrationId(context, regid);
                } catch (IOException ex) {
                    msg = "Error :" + ex.getMessage();
                }
                Log.i("FastServiceGCM Post Register",msg);
                return msg;
            }
            @Override
            protected void onPostExecute(String msg) {
                Log.i("FastServiceGCM Post Register",msg);
            }
        }.execute(null, null, null);
    }

    private void storeRegistrationId(Context context, String regId) {
        final SharedPreferences prefs = getGCMPreferences(context);
        int appVersion = getAppVersion(context);
        Log.i("FastServiceGCM", "Saving regId on app version " + appVersion);
        SharedPreferences.Editor editor = prefs.edit();
        editor.putString(PROPERTY_REG_ID, regId);
        editor.putInt(PROPERTY_APP_VERSION, appVersion);
        editor.commit();

        editor = context.getSharedPreferences("FastServicePref", 0).edit(); // 0 - for private mode
        editor.putString(PROPERTY_REG_ID, regId);
        editor.commit();



    }

    @Override
    protected void onResume() {
        super.onResume();
        ActionBar actionBar = getActionBar();
        actionBar.hide();
        getElemtsFromLayout();
        setListeners();
        checkPlayServices();
        checkLoggedUser();
    }

    private boolean checkPlayServices() {
        int resultCode = GooglePlayServicesUtil.isGooglePlayServicesAvailable(this);
        if (resultCode != ConnectionResult.SUCCESS) {
            if (GooglePlayServicesUtil.isUserRecoverableError(resultCode)) {
                GooglePlayServicesUtil.getErrorDialog(resultCode, this,
                        PLAY_SERVICES_RESOLUTION_REQUEST).show();
            } else {
                Log.i("Fast Service GCM", "This device is not supported.");
                finish();
            }
            return false;
        }
        return true;
    }

    private void checkLoggedUser(){
        String loggedUser = Utils.getLoggedUser(this);
        if(loggedUser!=null){
            Intent intent = new Intent(LoginActivity.this,InstruccionesActivity.class);
            bd = new BD();
            JSONArray ticketsPentientes = bd.obtenerTicketAbiertoDeUsuario(Utils.getLoggedUser(context));
            if (ticketsPentientes == null){
                Utils.showTimeoutAlert(context);
            }
            else{
                if (ticketsPentientes.length()!=0){
                    intent = new Intent(LoginActivity.this,PedidoActivity.class);
                }
                startActivity(intent);
                finish();
            }
        }
    }

    private void getElemtsFromLayout(){
        register = (TextView) findViewById(R.id.textRegister);
        register.setText(Html.fromHtml("<p><u>¡Registrate!</u></p>"));
        user = (EditText) findViewById(R.id.editTextUser);
        password = (EditText) findViewById(R.id.editTextPass);
        login = (Button) findViewById(R.id.buttonLogin);
    }

    private void setListeners(){
        login.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                String u = user.getText().toString().trim();
                String p = password.getText().toString().trim();
                if ((!u.equals("")) && (!p.equals(""))) {
                    bd=new BD();
                    JSONArray resultado = bd.obtenerUsuario(u);
                    if (resultado == null){
                        Utils.showTimeoutAlert(context);
                    }
                    else{
                        if (resultado.length() == 1){
                            JSONObject usuario = null;
                            try {
                                usuario = resultado.getJSONObject(0);
                                String user_BD = usuario.getString("nombre_usuario");
                                String hash_password_BD = usuario.getString("password_hash");
                                checkLogin(user_BD,hash_password_BD);
                            } catch (JSONException e) {
                                e.printStackTrace();
                            }
                        }
                        else if(resultado.length() == 0){
                            Utils.showToast(getApplicationContext(), "No existe ese usuario en el sistema");
                        }
                    }
                }
                else{
                    Utils.showToast(getApplicationContext(), "Los campos de Usuario y Password no pueden estar vacios");
                }
            }
        });
        register.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                startActivity(new Intent(LoginActivity.this,RegistroActivity.class));
            }
        });
    }

    private void checkLogin(String user_BD,String hash_password_BD){
        String u = user.getText().toString();
        String p = password.getText().toString();
        if (u.equals(user_BD) && Utils.getPasswordHash(p).equals(hash_password_BD)){
            Utils.showToast(getApplicationContext(), "Logeado correctamente");
            Utils.login(this,u);

            Log.i("GCM_KEY",Utils.getLoggedUserGcmKey(context));
            bd = new BD();
            bd.actualizarGcmUsuario(u,Utils.getLoggedUserGcmKey(context));

            bd = new BD();
            JSONArray ticketsPentientes = bd.obtenerTicketAbiertoDeUsuario(Utils.getLoggedUser(context));
            if (ticketsPentientes == null){
                Utils.showTimeoutAlert(context);
            }
            else{
                Intent intent = new Intent(LoginActivity.this,InstruccionesActivity.class);
                if (ticketsPentientes.length()!=0){
                    intent = new Intent(LoginActivity.this,PedidoActivity.class);
                }
                startActivity(intent);
                finish();
            }
        }
        else{
            Utils.showToast(getApplicationContext(), "La contraseña facilitada no es correcta");
        }
    }

}
